@@ -314,9 +314,11 @@ my %VALID_FLAGS = (
     DEFAULT => 1,
     ALT     => 1,
     DEBIAN  => 1,
+    EULER   => 1,
     FEDORA  => 1,
     FREEBSD => 1,
     GLIBC   => 1,
+    KYLIN   => 1,
     NETBSD  => 1,
     OPENBSD => 1,
     OSX     => 1,
